@@ -19,7 +19,7 @@ int main(int argc, char *argv[])
     MainWindow w(&a, player);
     w.show();
 
-    //SymfonieMetaReader reader;
-   // reader.start();
+    SymfonieMetaReader reader;
+    reader.start();
     return a.exec();
 }
