@@ -3,7 +3,7 @@
 #include <QFileSystemModel>
 #include <QTreeView>
 #include <QListWidget>
-#include <phonon>
+#include <Phonon>
 #include <QPushButton>
 //#include <QMaemo5InformationBox>
 #include "mainwindow.h"
@@ -20,7 +20,7 @@
 #include "symfonieaboutdialog.h"
 #include "symfonietimerwindow.h"
 #include "symfonieequalizerwindow.h"
-#include "symfoniefiletypesdialog.h"
+
 
 
 MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWidget *parent) :
@@ -28,24 +28,18 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         app(app),
         ui(new Ui::MainWindow),
         timerWindow(NULL),
-        fileTypesDialog(NULL),
         player(player),
-        equalizerWindow(new SymfonieEqualizerWindow(this)),
+        equalizerWindow(new SymfonieEqualizerWindow(this->getPlayer()->getEqualizerEffect(), this)),
 
         isInPortait(false),
         isResumePlayback(false)
 {
-    this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
 
     setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
 
-
     this->ui->mainToolBar2->hide();
 
-
-
-
     //set up menus
     orientationGroup = new QActionGroup(this);
     orientationGroup->setExclusive(true);
@@ -69,17 +63,12 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
 
 
-
-    connect(this->ui->menuActionFileTypes, SIGNAL(triggered()), this, SLOT(showFileTypesWindowSlot()));
-
-
     this->toggleFullScreenAction = new QAction(QIcon::fromTheme("general_fullsize"), QString(), this);
     this->toggleFullScreenAction->setCheckable(true);
     connect(this->toggleFullScreenAction, SIGNAL(toggled(bool)), this, SLOT(toggleFullScreen(bool)));
 
 
 
-
     connect(this->getPlayer(), SIGNAL(timerStoppedSignal()), this, SLOT(playerTimerStoppedSlot()));
     connect(this->getPlayer(), SIGNAL(timerRemainTimeChangedSignal(int)), this, SLOT(playerTimerRemainTimeChangedSlot(int)));
 
@@ -93,16 +82,6 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     connect(this->ui->menuActionTimer, SIGNAL(triggered()), this, SLOT(showTimerWindowSlot()));
 
-
-
-    //init equalizer window
-    bool isEqualizerEnabled = SymfonieDb::getInstance()->getSetting("is_equalizer_enabled", QVariant(0)).toInt() == 0 ? false : true;
-
-    connect(this->equalizerWindow,  SIGNAL(enabledStateChanged(bool)), this, SLOT(equalizerWindowEnabledStateChangedSlot(bool)));
-    qDebug() << " this->equalizerWindow->setWindowEnabled(isEqualizerEnabled);" << isEqualizerEnabled;
-    this->equalizerWindow->setWindowEnabled(isEqualizerEnabled);
-
-
     connect(this->ui->menuActionEqualizer, SIGNAL(triggered()), this, SLOT(showEqualizerWindowSlot()));
 
 
@@ -154,7 +133,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
 
 
-    this->goUpAction =  new QAction(QIcon::fromTheme("filemanager_folder_up"), tr("Go Up"), ui->mainToolBar);
+    this->goUpAction =  new QAction(style()->standardIcon(QStyle::SP_ArrowUp), tr("Go Up"), ui->mainToolBar);
     connect(goUpAction, SIGNAL(triggered()), this, SLOT(goUpSlot()));
 
     this->switchOrientationAction = new QAction(style()->standardIcon(QStyle::SP_BrowserReload),
@@ -166,16 +145,16 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(showInfoWindowAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
-    this->showToolBar2Action  = new QAction(QIcon::fromTheme("general_speaker"), tr("Show Volume"), ui->mainToolBar);
+    this->showToolBar2Action  = new QAction(style()->standardIcon(QStyle::SP_MediaVolume), tr("Show Volume"), ui->mainToolBar);
     this->showToolBar2Action->setCheckable(true);
     connect(showToolBar2Action, SIGNAL(triggered()), this, SLOT(showToolBar2Slot()));
 
 
-    this->goHomeAction = new QAction(QIcon::fromTheme("general_device_root_folder"), tr("Go Home"), ui->mainToolBar);
+    this->goHomeAction = new QAction(style()->standardIcon(QStyle::SP_ComputerIcon), tr("Go Home"), ui->mainToolBar);
     connect(goHomeAction, SIGNAL(triggered()), this, SLOT(goHomeSlot()));
 
 
-    this->goToCurDir = new QAction(QIcon::fromTheme("imageviewer_rotate"), tr("Go to current directory"), ui->mainToolBar);
+    this->goToCurDir = new QAction(style()->standardIcon(QStyle::SP_DesktopIcon), tr("Go to current directory"), ui->mainToolBar);
     connect(goToCurDir, SIGNAL(triggered()), this, SLOT(goToCurDirSlot()));
 
     connect(playAction, SIGNAL(triggered()), this, SLOT(playSlot()));
@@ -221,6 +200,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     //ui->mainToolBar->addWidget(slider);
     connect(this->player, SIGNAL(scanDirCompletedSignal(SymfoniePlayList*, QString)),
             this, SLOT(playerScanDirCompletedSlot(SymfoniePlayList*, QString)));
+    this->player->init();
 
 
     QString lastPlayedFile = SymfonieDb::getInstance()->getSetting("last_played_file").toString();
@@ -277,15 +257,10 @@ MainWindow::~MainWindow()
     if(this->timerWindow != NULL){
         delete this->timerWindow;
     }
-    delete this->player;
-
-    delete this->equalizerWindow;
-
-    if(this->fileTypesDialog == NULL){
-        delete this->fileTypesDialog;
+    if(this->equalizerWindow != NULL){
+        delete this->equalizerWindow;
     }
-
-
+    delete this->player;
 }
 
 void MainWindow::playerTimerStoppedSlot(){
@@ -375,33 +350,6 @@ void MainWindow::setMenuActionTimerText(int time){
 
 }
 
-void MainWindow::equalizerWindowEnabledStateChangedSlot(bool value){
-    qDebug() << "equalizerWindowEnabledStateChangedSlot called" << value;
-    if(value){
-        if(this->getPlayer()->insertEqualizerEffect()){
-            this->equalizerWindow->setEqualizerEffect(this->getPlayer()->getEqualizerEffect());
-
-        }
-    }else{
-        this->getPlayer()->removeEqualizerEffect();
-    }
-}
-
-
-void MainWindow::showFileTypesWindowSlot(){
-    if(this->fileTypesDialog == NULL){
-        this->fileTypesDialog = new SymfonieFileTypesDialog();
-        connect(this->fileTypesDialog, SIGNAL(fileTypesChanged(QStringList)),
-                this, SLOT(fileTypesChangedSlot(QStringList)));
-    }
-
-    qDebug() << "this->fileTypesDialog->exec()" << this->fileTypesDialog->exec();
-}
-
-void MainWindow::fileTypesChangedSlot(QStringList list){
-  this->getPlayer()->setFileFilter(list);
-}
-
 void MainWindow::playerTimerRemainTimeChangedSlot(int time){
     qDebug() << "playerTimerRemainTimeChangedSlot: " << time;
 
@@ -624,12 +572,11 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
 
 
         if(item->getItemType() == SymfoniePlayListItem::Directory){
-            newItem->setIcon(QIcon::fromTheme("filemanager_audio_folder"));
+            newItem->setIcon(style()->standardIcon(QStyle::SP_DirIcon));
         }else if(item->getItemType() == SymfoniePlayListItem::File){
-            newItem->setIcon(QIcon::fromTheme("general_audio_file"));
+            newItem->setIcon(style()->standardIcon(QStyle::SP_FileIcon));
         }else if(item->getItemType() == SymfoniePlayListItem::DotDot){
-            newItem->setIcon(QIcon::fromTheme("filemanager_folder_up"));
-
+            newItem->setIcon(style()->standardIcon(QStyle::SP_ArrowUp));
         }
 
 
