@@ -5,7 +5,7 @@
 #include <QModelIndex>
 #include <QPushButton>
 #include <QAction>
-#include <phonon>
+#include <Phonon>
 #include <QListWidgetItem>
 
 
@@ -17,7 +17,6 @@ class QTimer;
 class QApplication;
 class SymfonieTimerWindow;
 class SymfonieEqualizerWindow;
-class SymfonieFileTypesDialog;
 
 
 namespace Ui {
@@ -52,7 +51,6 @@ private:
     SymfonieTimerWindow *timerWindow;
     SymfonieEqualizerWindow *equalizerWindow;
     const QApplication *app;
-    SymfonieFileTypesDialog *fileTypesDialog;
 
 
     QAction *playAction;
@@ -117,9 +115,6 @@ private Q_SLOTS:
     void playerTimerStoppedSlot();
     void clearTimerSlot();
     void playerTimerRemainTimeChangedSlot(int);
-    void equalizerWindowEnabledStateChangedSlot(bool value);
-    void showFileTypesWindowSlot();
-    void fileTypesChangedSlot(QStringList list);
 
 };
 
