@@ -2,7 +2,7 @@
 #define SYMFONIEEQUALIZERWINDOW_H
 
 #include <QMainWindow>
-#include <phonon>
+#include <Phonon>
 
 class QStringList;
 class SymfonieQSlider;
@@ -14,24 +14,14 @@ namespace Ui {
 class SymfonieEqualizerWindow : public QMainWindow {
     Q_OBJECT
 public:
-    SymfonieEqualizerWindow(QWidget *parent = 0);
+    SymfonieEqualizerWindow(Phonon::Effect *effect, QWidget *parent = 0);
     ~SymfonieEqualizerWindow();
     void saveBandValue(int band, int value);
     int getBandValue(int band);
     void saveState();
 
-    bool getIsEnabled();
-    void setEqualizerEffect(Phonon::Effect *effect);
-    void syncSlidersValues();
-
-
-Q_SIGNALS:
-    void enabledStateChanged(bool);
-
-
 public Q_SLOTS:
     void slideValueChangedSlot(int index, int value);
-    void setWindowEnabled(bool);
 
 protected:
     void changeEvent(QEvent *e);
@@ -44,8 +34,6 @@ private:
 
    static const int EQ_BAR_MIN = 1; //0
    static const int EQ_BAR_MAX = 9; //10
-
-   bool isEnabled;
 };
 
 #endif // SYMFONIEEQUALIZERWINDOW_H
