@@ -1,33 +1,25 @@
 #include <QDir>
 #include <QScrollArea>
 #include <QDesktopServices>
-#include <phonon>
+#include <Phonon>
 #include "symfoniemediaplayer.h"
 #include "symfonieplaylist.h"
 #include "symfonieplaylistitem.h"
 #include "symfonieplaylistitemfolder.h"
 #include "symfoniesong.h"
 #include "symfoniedb.h"
-#include "symfoniefiletypesdialog.h"
 
 SymfonieMediaPlayer::SymfonieMediaPlayer(QObject *parent) :
         QObject(parent),
         playList(NULL),
         timer(new QTimer()),
         timerUpdater(new QTimer()),
-        equalizerEffect(NULL),
         currentPlaybackIndex(-1),
         queuedIndex(-1),
         seekToBuffer(-1),
-        timerRemainCounter(0),
-        hasEqualizerEffect(false),
-        isEqualizerEnabled(false)
-{
-    this->initPlayer();
-}
+        timerRemainCounter(0){
 
 
-void SymfonieMediaPlayer::initPlayer(){
     this->timer->setSingleShot(true);
     connect(timer, SIGNAL(timeout()), this, SLOT(timerEndSlot()));
 
@@ -41,10 +33,6 @@ void SymfonieMediaPlayer::initPlayer(){
     this->audioOutput = new Phonon::AudioOutput;
     this->path = Phonon::createPath(player, audioOutput);
 
-
-    this->setFileFilter(SymfonieFileTypesDialog::getSavedFilterList());
-
-
     connect(this->player, SIGNAL(stateChanged(Phonon::State,Phonon::State)),
             this, SLOT(mediaStateChangedSlot(Phonon::State,Phonon::State)));
 
@@ -55,12 +43,24 @@ void SymfonieMediaPlayer::initPlayer(){
     connect(this, SIGNAL(playListUpdatedSignal(SymfoniePlayList*)),
             this, SLOT(playListUpdatedSlot(SymfoniePlayList*)));
 
+    QList<Phonon::EffectDescription> effectDescriptions =
+            Phonon::BackendCapabilities::availableAudioEffects();
 
-
+    qDebug() << effectDescriptions.size() << " effect size";
+    for(int i = 0; i < effectDescriptions.size(); i++){
+        Phonon::EffectDescription ef = effectDescriptions.at(i);
+        if(QString::compare(ef.name(), "equalizer-10bands") == 0){
+            this->equalizerEffect = new Phonon::Effect(ef);
+            path.insertEffect(this->equalizerEffect );
+            qDebug() << "Effect inserted: " << ef.name();
+        }
+        qDebug() << ef.name();
+    }
 
 
     this->timerUpdater->setInterval(SymfonieMediaPlayer::TIMER_VALUE_UPDATE_RATE);
     connect(this->timerUpdater, SIGNAL(timeout()), this, SLOT(updateTimerValueSlot()));
+
 }
 
 SymfonieMediaPlayer::~SymfonieMediaPlayer()
@@ -71,49 +71,6 @@ SymfonieMediaPlayer::~SymfonieMediaPlayer()
     delete this->timer;
     delete this->timerUpdater;
 
-
-
-
-}
-
-
-
-bool SymfonieMediaPlayer::insertEqualizerEffect(){
-    if(!this->isEqualizerEnabled){
-        QList<Phonon::EffectDescription> effectDescriptions =
-                Phonon::BackendCapabilities::availableAudioEffects();
-
-        qDebug() << effectDescriptions.size() << " effect size";
-
-        for(int i = 0; i < effectDescriptions.size(); i++){
-            Phonon::EffectDescription ef = effectDescriptions.at(i);
-            if(QString::compare(ef.name(), "equalizer-10bands") == 0){
-                this->equalizerEffect = new Phonon::Effect(ef);
-                if(path.insertEffect(this->equalizerEffect )){
-                    this->hasEqualizerEffect = true;
-                    this->isEqualizerEnabled = true;
-                    emit equalizerEffectInsertedSignal();
-                    qDebug() << "Effect inserted: " << ef.name();
-                    return true;
-                }else{
-                    qDebug() << "Effect insertion failed: " << ef.name();
-                }
-
-            }
-            qDebug() << ef.name();
-        }
-    }
-    return false;
-}
-
-
-void SymfonieMediaPlayer::removeEqualizerEffect(){
-    if(this->isEqualizerEnabled){
-        this->path.removeEffect(this->equalizerEffect);
-        this->isEqualizerEnabled = false;
-
-        emit equalizerEffectRemovedSignal();
-    }
 }
 
 void SymfonieMediaPlayer::doTimer(int time){
@@ -161,6 +118,15 @@ Phonon::AudioOutput* SymfonieMediaPlayer::getAudioOutput(){
     return this->audioOutput;
 }
 
+void SymfonieMediaPlayer::init(){
+    //this->setCurrentDirectory(QDir::homePath ());// + "/MyDocs/.sounds";
+    
+    //this->scanDir(QDir::homePath () + "/MyDocs/m", true);
+    // this->scanDir(QDir::homePath () + "/MyDocs/.sounds", true);
+    // qDebug() << "Music location: " << QDesktopServices::storageLocation(QDesktopServices::MusicLocation);
+    //this->setCurrentDirectory(QDesktopServices::storageLocation(QDesktopServices::MusicLocation));
+
+}
 
 void SymfonieMediaPlayer::saveState(){
     int index = this->getCurrentPlaybackIndex();
@@ -175,8 +141,6 @@ void SymfonieMediaPlayer::saveState(){
     SymfonieDb::getInstance()->saveSetting(
             "last_played_index",
             index);
-
-    SymfonieDb::getInstance()->saveSetting("is_equalizer_enabled", QVariant(this->isEqualizerEnabled == true ? 1: 0));
 }
 
 
@@ -205,18 +169,16 @@ Phonon::MediaObject *SymfonieMediaPlayer::getMediaObject(){
 }
 
 
-void SymfonieMediaPlayer::setFileFilter(QStringList filterList){
-    this->fileFilterList = filterList;
-}
-
 //remove any entry in the list
 SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){//bool isUpdatePlayList){
-
     QDir directory(path);
 
     SymfoniePlayList *playList = new SymfoniePlayList(path);
 
-    QStringList fileList = directory.entryList(this->fileFilterList);
+    QStringList filters;
+    filters << "*.mp3";
+
+    QStringList fileList = directory.entryList(filters);
     QStringList dirList = directory.entryList(
             QStringList(),
             QDir::Dirs|QDir::NoDotAndDotDot|QDir::Drives|QDir::AllDirs
@@ -245,18 +207,14 @@ SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){//bool isUpdatePlay
 
     }
 
-    if(this->fileFilterList.size() > 0){
 
+    for (int i = 0; i < fileList.size(); i++) {
+        QFileInfo fileInfo(path + "/" +fileList.at(i));
+        QString filePath = fileInfo.canonicalFilePath();
 
+        SymfoniePlayListItemFile *file =  new SymfoniePlayListItemFile(filePath);
 
-        for (int i = 0; i < fileList.size(); i++) {
-            QFileInfo fileInfo(path + "/" +fileList.at(i));
-            QString filePath = fileInfo.canonicalFilePath();
-
-            SymfoniePlayListItemFile *file =  new SymfoniePlayListItemFile(filePath);
-            file->setDisplayName(fileInfo.fileName());
-
-            /*
+/*
         SymfonieSong *song = SymfonieSong::findByFilePath(filePath);
         if(song != NULL){
 
@@ -273,8 +231,7 @@ SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){//bool isUpdatePlay
         file->setSong(song);
 */
 
-            playList->addFile(file);
-        }
+        playList->addFile(file);
     }
 
     qDebug() << playList->getSize() << "size";
