@@ -12,10 +12,6 @@
 #include "symfonieplaylist.h"
 
 
-
-
-
-class QStringList;
 class QTimer;
 
 class SymfonieMediaPlayer : public QObject
@@ -41,9 +37,7 @@ public:
     void setPlayList(SymfoniePlayList*);
     Phonon::AudioOutput* getAudioOutput();
 
-    bool insertEqualizerEffect();
-    void removeEqualizerEffect();
-
+    void init();
     bool isCanPlay();
     QString getFilePathAt(int index);
     void fetchSongInfo(QString path);
@@ -60,32 +54,27 @@ public:
     void doTimer(int time);
     void stopTimer();
     int getTimerRemain();
-    void setFileFilter(QStringList filterList);
 
 
 
 
 
 Q_SIGNALS:
-    void directoryChangedSignal(QString);
-    void scanDirCompletedSignal(SymfoniePlayList*, QString);
-    void mediaStateChangedSignal( Phonon::State newstate, Phonon::State oldstate);
-    void playListUpdatedSignal(SymfoniePlayList* playList);
-    void timerStoppedSignal();
-    void timerRemainTimeChangedSignal(int);
-
-    void equalizerEffectInsertedSignal();
-    void equalizerEffectRemovedSignal();
+     void directoryChangedSignal(QString);
+     void scanDirCompletedSignal(SymfoniePlayList*, QString);
+     void mediaStateChangedSignal( Phonon::State newstate, Phonon::State oldstate);
+     void playListUpdatedSignal(SymfoniePlayList* playList);
+     void timerStoppedSignal();
+     void timerRemainTimeChangedSignal(int);
 
 
 public Q_SLOTS:
-    void mediaStateChangedSlot( Phonon::State newstate, Phonon::State oldstate);
-    void aboutToFinishSlot();
-    void currentSourceChangedSlot ( const Phonon::MediaSource & newSource );
-    void playListUpdatedSlot(SymfoniePlayList* playList);
-    void oneCompletedSlot();
-    void timerEndSlot();
-
+     void mediaStateChangedSlot( Phonon::State newstate, Phonon::State oldstate);
+     void aboutToFinishSlot();
+     void currentSourceChangedSlot ( const Phonon::MediaSource & newSource );
+     void playListUpdatedSlot(SymfoniePlayList* playList);
+     void oneCompletedSlot();
+     void timerEndSlot();
 
 
 
@@ -94,7 +83,7 @@ private Q_SLOTS:
 
 
 protected:
-    void setCurrentDirectory(QString dir);
+      void setCurrentDirectory(QString dir);
 
 
 private:
@@ -102,10 +91,6 @@ private:
     Phonon::AudioOutput *audioOutput;
     Phonon::Path path;
     Phonon::Effect *equalizerEffect;
-    bool hasEqualizerEffect;
-    bool isEqualizerEnabled;
-
-    void initPlayer();
 
     QString currentDirectory;
     SymfoniePlayList *playList;
@@ -118,9 +103,7 @@ private:
 
     int timerRemainCounter; //why do I need to implement this?
 
-    static const int TIMER_VALUE_UPDATE_RATE = 3000; //msec
-
-    QStringList fileFilterList;
+ static const int TIMER_VALUE_UPDATE_RATE = 3000; //msec
 
 
 
